
globalVariables(c('.',
									'Bin',
									'Class',
									'Count',
									'File',
									'Mode',
									'Scan',
									'intensity',
									'mz',
									'n',
									'Sample',
									'seqNum',
									'acquisitionNum',
									'polarity',
									'totIonCurrent',
									'FileName',
									'Colour',
									'Index',
									'LowerOut',
									'Median',
									'Q1',
									'Q3',
									'UpperOut',
									'TIC',
									'Feature',
									'Intensity',
									'm/z'
))
